<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Event\Backport;

// Prevent direct access
defined('_JEXEC') or die;

use Joomla\Event\Event as BaseEvent;

/**
 * This Trait partially implements the ResultAwareInterface for mutable and immutable events.
 *
 * You must additionally implement the typeCheckResult method or use one of the ResultType*Aware
 * traits in your Event handler.
 *
 * IMPORTANT: THIS IS A BACKPORT FROM MY CONTRIBUTED CODE TO JOOMLA FOR IMPROVING EVENTS HANDLING IN JOOMLA 4.X. THIS
 * CODE WILL BE REMOVED WHEN WE DROP SUPPORT FOR JOOMLA VERSIONS WHICH DO NOT INCLUDE THIS CODE.
 *
 * @since  6.0.0
 */
trait ResultAware
{
	/**
	 * Disallow setting the result argument directly with setArgument() instead of going through addResult().
	 *
	 * @var    boolean
	 * @since      6.0.0
	 *
	 * @deprecated 7.0 Using setArgument() for the result argument will always be disallowed.
	 */
	protected $preventSetArgumentResult = false;

	/**
	 * Appends data to the result array of the event.
	 *
	 * @param   mixed  $data  What to add to the result array.
	 *
	 * @return  void
	 * @since   6.0.0
	 */
	public function addResult($data): void
	{
		// Ensure this trait is applied to an Event object.
		if (!($this instanceof BaseEvent))
		{
			throw new \LogicException(sprintf('Event class ‘%s‘ must implement %s.', get_class($this), BaseEvent::class));
		}

		// Ensure the Event object fully implements the ResultAwareInterface.
		if (!($this instanceof ResultAwareInterface))
		{
			throw new \LogicException(sprintf('Event class ‘%s‘ must implement %s.', get_class($this), ResultAwareInterface::class));
		}

		// Make sure the data type is correct
		$this->typeCheckResult($data);

		// Append the result. We use the arguments property directly to allow this to work on immutable events.
		$result                    = $this['result'] ?? [];
		$result[]                  = $data;
		$this->arguments['result'] = $result;
	}

	/**
	 * Handle setting the result argument directly.
	 *
	 * This method serves a dual purpose: backwards compatibility and enforcing the use of addResult.
	 *
	 * When $this->preventSetArgumentResult is false it acts as a backwards compatibility shim for event handlers
	 * expecting generic event classes instead of the concrete Events implemented here. This allows the migration to
	 * concrete event classes.
	 *
	 * When $this->preventSetArgumentResult is false it will throw a BadMethodCallException if the developer tries to
	 * call setArgument('result', ...) instead of going through the addResult() method.
	 *
	 * @param   array  $value  The new result array.
	 *
	 * @return  void
	 * @since   6.0.0
	 */
	protected function setResult(array $value)
	{
		if ($this->preventSetArgumentResult)
		{
			throw new \BadMethodCallException('You are not allowed to set the result argument directly. Use addResult() instead.');
		}

		// Always assume that the last element of the array is the result the handler is trying to append.
		$latestValue = array_pop($value);

		$this->addResult($latestValue);

		return $this->arguments['result'];
	}
}