<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Event;

defined('_JEXEC') or die;

use DomainException;
use Joomla\CMS\Event\AbstractImmutableEvent;

/**
 * Concrete Event class for the onLoginGuardCallback event
 *
 * @package     Akeeba\Component\LoginGuard\Administrator\Event
 *
 * @since       6.0.0
 */
class Callback extends AbstractImmutableEvent
{
	/** @inheritdoc */
	public function __construct(string $method)
	{
		parent::__construct('onLoginGuardCallback', [
			'method' => $method,
		]);
	}

	/**
	 * Validate the value of the 'method' named parameter
	 *
	 * @param   string|null  $value
	 *
	 * @return  string
	 * @throws  DomainException
	 * @since   6.0.0
	 */
	public function setMethod(string $value): string
	{
		if (empty($value))
		{
			throw new DomainException(sprintf("Argument 'methhod' of event %s must be a non-empty string.", $this->name));
		}

		return $value;
	}
}