<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Model;

// Prevent direct access
defined('_JEXEC') or die;

use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\Database\ParameterType;

class WelcomeModel extends BaseDatabaseModel
{
	/**
	 * Are there any published LoginGuard plugins in the specified folder?
	 *
	 * @return  bool
	 */
	public function isLoginGuardPluginPublished($folder)
	{
		return PluginHelper::isEnabled($folder, 'loginguard');
	}


	/**
	 * Are there any published LoginGuard plugins?
	 *
	 * @return  bool
	 */
	public function hasPublishedPlugins()
	{
		return !empty(PluginHelper::getPlugin('loginguard'));
	}

	/**
	 * Are there any installed LoginGuard plugins?
	 *
	 * Since Joomla's PLuginHelper only returned published plugins we need to go through the database to find out if
	 * there are installed but unpublished plugins.
	 *
	 * @return  bool
	 */
	public function hasInstalledPlugins()
	{
		$db     = $this->getDbo();
		$type   = 'plugin';
		$folder = 'loginguard';
		$query  = $db->getQuery(true)
			->select('COUNT(*)')
			->from($db->qn('#__extensions'))
			->where($db->qn('type') . ' = :type')
			->where($db->qn('folder') . ' = :folder')
			->bind(':type', $type, ParameterType::STRING)
			->bind(':folder', $folder, ParameterType::STRING);

		try
		{
			return !empty($db->setQuery($query)->loadResult());
		}
		catch (\Exception $e)
		{
			return false;
		}
	}

	/**
	 * Do I need to migrate Joomla Two Factor Authentication information into Akeeba LoginGuard?
	 *
	 * @return  bool
	 */
	public function needsMigration()
	{
		// Get the Users with Joomla! TFA records
		$db     = $this->getDbo();
		$empty1 = '';
		$empty2 = '';
		$query  = $db->getQuery(true)
			->select('COUNT(*)')
			->from($db->qn('#__users'))
			->where($db->qn('otpKey') . ' != :empty1')
			->where($db->qn('otep') . ' != :empty2')
			->bind(':empty1', $empty1, ParameterType::STRING)
			->bind(':empty2', $empty2, ParameterType::STRING);
		$result = $db->setQuery($query)->loadResult();

		return !empty($result);
	}
}