<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\View\Method;

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Model\MethodModel;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\User\User;
use Joomla\CMS\User\UserFactoryInterface;

class HtmlView extends BaseHtmlView
{
	/**
	 * Is this an administrator page?
	 *
	 * @var   bool
	 */
	public $isAdmin = false;

	/**
	 * The editor page render options
	 *
	 * @var   array
	 */
	public $renderOptions = [];

	/**
	 * The TFA Method record being edited
	 *
	 * @var   object
	 */
	public $record = null;

	/**
	 * The title text for this page
	 *
	 * @var  string
	 */
	public $title = '';

	/**
	 * The return URL to use for all links and forms
	 *
	 * @var   string
	 */
	public $returnURL = null;

	/**
	 * The user object used to display this page
	 *
	 * @var   User
	 */
	public $user = null;

	/**
	 * The backup codes for the current user. Only applies when the backup codes record is being "edited"
	 *
	 * @var   array
	 */
	public $backupCodes = [];

	/**
	 * Am I editing an existing Method? If it's false then I'm adding a new Method.
	 *
	 * @var   bool
	 */
	public $isEditExisting = false;

	/**
	 * @inheritDoc
	 */
	function display($tpl = null)
	{
		$app = Factory::getApplication();

		if (empty($this->user))
		{
			$this->user = Factory::getApplication()->getIdentity()
				?: Factory::getContainer()->get(UserFactoryInterface::class)->loadUserById(0);
		}

		/** @var MethodModel $model */
		$model = $this->getModel();
		$this->setLayout('edit');
		$this->renderOptions = $model->getRenderOptions($this->user);
		$this->record        = $model->getRecord($this->user);
		$this->title         = $model->getPageTitle();
		$this->isAdmin       = $app->isClient('administrator');

		// Backup codes are a special case, rendered with a special layout
		if ($this->record->method == 'backupcodes')
		{
			$this->setLayout('backupcodes');

			$backupCodes = $this->record->options;

			if (!is_array($backupCodes))
			{
				$backupCodes = [];
			}

			$backupCodes = array_filter($backupCodes, function ($x) {
				return !empty($x);
			});

			if (count($backupCodes) % 2 != 0)
			{
				$backupCodes[] = '';
			}

			/**
			 * The call to array_merge resets the array indices. This is necessary since array_filter kept the indices,
			 * meaning our elements are completely out of order.
			 */
			$this->backupCodes = array_merge($backupCodes);
		}

		// Set up the isEditExisting property.
		$this->isEditExisting = !empty($this->record->id);

		// Back-end: always show a title in the 'title' module position, not in the page body
		if ($this->isAdmin)
		{
			ToolbarHelper::title($this->title, 'loginguard');

			$helpUrl = $this->renderOptions['help_url'];

			if (!empty($helpUrl))
			{
				ToolbarHelper::help('', false, $helpUrl);
			}

			$this->title = '';
		}

		// Include CSS
		$wam = $this->document->getWebAssetManager();
		$wam->useStyle('com_loginguard.methods');

		if (ComponentHelper::getParams('com_loginguard')->get('dark_mode') != 0)
		{
			$wam->useStyle('com_loginguard.dark');
		}

		// Display the view
		parent::display($tpl);
	}
}