<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\View\Welcome;

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Model\WelcomeModel;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Toolbar\ToolbarHelper;

class HtmlView extends BaseHtmlView
{
	/**
	 * Is the user plugin missing / disabled?
	 *
	 * @var   bool
	 */
	public $noUserPlugin = false;

	/**
	 * Is the system plugin missing / disabled?
	 *
	 * @var   bool
	 */
	public $noSystemPlugin = false;

	/**
	 * Are no published Methods detected?
	 *
	 * @var   bool
	 */
	public $noMethods = false;

	/**
	 * Are no loginguard plugins installed?
	 *
	 * @var   bool
	 */
	public $notInstalled = false;

	/**
	 * Do we have to migrate from Joomla's Two Factor Authentication?
	 *
	 * @var   bool
	 */
	public $needsMigration = false;

	/**
	 * @inheritDoc
	 */
	function display($tpl = null)
	{
		/** @var WelcomeModel $model */
		$model = $this->getModel();

		$this->noMethods      = !$model->hasPublishedPlugins();
		$this->notInstalled   = !$model->hasInstalledPlugins();
		$this->noUserPlugin   = !$model->isLoginGuardPluginPublished('user');
		$this->noSystemPlugin = !$model->isLoginGuardPluginPublished('system');
		$this->needsMigration = $model->needsMigration();

		// Show a title and the component's Options button
		ToolbarHelper::title(Text::_('COM_LOGINGUARD_HEAD_WELCOME'), 'loginguard');
		ToolbarHelper::link('index.php?option=com_loginguard&view=Users', 'COM_LOGINGUARD_HEAD_USERS', 'users');
		ToolbarHelper::help('', false, 'https://github.com/akeeba/loginguard/wiki');
		ToolbarHelper::preferences('com_loginguard');

		// Display the view
		parent::display($tpl);
	}
}