<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Model\MethodsModel;
use Akeeba\Component\LoginGuard\Administrator\View\Methods\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Session\Session;
use Joomla\CMS\Uri\Uri;

/** @var HtmlView $this */

HTMLHelper::_('bootstrap.tooltip', '.hasTooltip');

/** @var MethodsModel $model */
$model = $this->getModel();

?>
<div id="loginguard-methods-list-container">
	<?php foreach($this->methods as $methodName => $method): ?>
        <div class="loginguard-methods-list-method loginguard-methods-list-method-name-<?= htmlentities($method['display'])?> <?= ($this->defaultMethod == $methodName) ? 'loginguard-Methods-list-Method-default' : ''?> ">
            <div class="loginguard-methods-list-method-header">
				<div class="loginguard-methods-list-method-image">
					<img src="<?= Uri::root() . $method['image'] ?>" alt="<?= $this->escape($method['name']) ?>">
				</div>
				<div class="loginguard-methods-list-method-title">
					<h4>
						<?= $method['display'] ?>
						<?php if ($this->defaultMethod == $methodName): ?>
							<span id="loginguard-methods-list-method-default-tag" class="badge bg-info me-1">
							<?= Text::_('COM_LOGINGUARD_LBL_LIST_DEFAULTTAG') ?>
							</span>
						<?php endif; ?>
					</h4>
				</div>
				<div class="loginguard-methods-list-method-info">
					<span class="hasTooltip icon icon-info-circle icon-info-sign"
						  title="<?= $this->escape($method['shortinfo']) ?>"></span>
				</div>
            </div>

            <div class="loginguard-methods-list-method-records-container">
				<?php if (count($method['active'])): ?>
                    <div class="loginguard-methods-list-method-records">
						<?php  foreach($method['active'] as $record): ?>
                            <div class="loginguard-methods-list-method-record">
								<div class="loginguard-methods-list-method-record-info">

									<?php if ($methodName == 'backupcodes'): ?>
										<div class="alert alert-info">
											<span class="icon icon-info-circle icon-info-sign"></span>
											<?= Text::sprintf('COM_LOGINGUARD_LBL_BACKUPCODES_PRINT_PROMPT', Route::_('index.php?option=com_loginguard&task=method.edit&id=' . (int) $record->id . ($this->returnURL ? '&returnurl=' . $this->escape(urlencode($this->returnURL)) : '') . '&user_id=' . $this->user->id)) ?>
										</div>
									<?php else: ?>
										<div class="loginguard-methods-list-method-record-title-container">
											<?php if ($record->default): ?>
												<span id="loginguard-methods-list-method-default-badge-small" class="badge bg-info me-1 hasTooltip" title="<?= $this->escape(Text::_('COM_LOGINGUARD_LBL_LIST_DEFAULTTAG')) ?>"><span class="icon icon-star"></span></span>
											<?php endif; ?>
											<span class="loginguard-methods-list-method-record-title">
                                            	<?= $this->escape($record->title); ?>
                                        	</span>
										</div>
									<?php endif; ?>

									<div class="loginguard-methods-list-method-record-lastused">
										<span class="loginguard-methods-list-method-record-createdon">
                                            <?= Text::sprintf('COM_LOGINGUARD_LBL_CREATEDON', $model->formatRelative($record->created_on)) ?>
                                        </span>
										<span class="loginguard-methods-list-method-record-lastused-date">
                                            <?= Text::sprintf('COM_LOGINGUARD_LBL_LASTUSED', $model->formatRelative($record->last_used)) ?>
                                        </span>
									</div>

								</div>

	                            <?php if ($methodName != 'backupcodes'): ?>
								<div class="loginguard-methods-list-method-record-actions">
									<a class="loginguard-methods-list-method-record-edit btn btn-secondary"
									   href="<?= Route::_('index.php?option=com_loginguard&task=method.edit&id=' . (int) $record->id . ($this->returnURL ? '&returnurl=' . $this->escape(urlencode($this->returnURL)) : '') . '&user_id=' . $this->user->id)?>">
										<span class="icon icon-pencil"></span>
									</a>

		                            <?php if ($method['canDisable']): ?>
										<a class="loginguard-methods-list-method-record-delete btn btn-danger"
										   href="<?= Route::_('index.php?option=com_loginguard&task=method.delete&id=' . (int) $record->id . ($this->returnURL ? '&returnurl=' . $this->escape(urlencode($this->returnURL)) : '') . '&user_id=' . $this->user->id . '&' . Factory::getApplication()->getFormToken() . '=1')?>"
										><span class="icon icon-trash"></span></a>
		                            <?php endif; ?>
								</div>
								<?php endif; ?>
                            </div>
						<?php endforeach; ?>
                    </div>
				<?php endif; ?>

				<?php if (empty($method['active']) || $method['allowMultiple']): ?>
                    <div class="loginguard-methods-list-method-addnew-container">
                        <a href="<?= Route::_('index.php?option=com_loginguard&task=method.add&method=' . $this->escape(urlencode($method['name'])) . ($this->returnURL ? '&returnurl=' . $this->escape(urlencode($this->returnURL)) : '') . '&user_id=' . $this->user->id)?>"
                           class="loginguard-methods-list-method-addnew btn btn-primary"
                        >
	                        <?= Text::sprintf('COM_LOGINGUARD_LBL_LIST_ADD_A', $method['display']) ?>
                        </a>
                    </div>
				<?php endif; ?>
            </div>
        </div>
	<?php endforeach; ?>
</div>